==> ansible-9.2.0.tar.gz: ansible-9.2.0/ansible_collections/cisco/ios/tests/unit/modules/network/ios/test_ios_command.py <==
# (c) 2016 Red Hat Inc.
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Ansible is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.

# Make coding more python3-ish
from __future__ import absolute_import, division, print_function


__metaclass__ = type

import json

from ansible_collections.cisco.ios.plugins.modules import ios_command
from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args

from .ios_module import TestIosModule, load_fixture


class TestIosCommandModule(TestIosModule):
    module = ios_command

    def setUp(self):
        super(TestIosCommandModule, self).setUp()

        self.mock_run_commands = patch(
            "ansible_collections.cisco.ios.plugins.modules.ios_command.run_commands",
        )
        self.run_commands = self.mock_run_commands.start()

    def tearDown(self):
        super(TestIosCommandModule, self).tearDown()
        self.mock_run_commands.stop()

    def load_fixtures(self, commands=None):
        def load_from_file(*args, **kwargs):
            module, commands = args
            output = list()

            for item in commands:
                try:
                    obj = json.loads(item["command"])
                    command = obj["command"]
                except ValueError:
                    command = item["command"]
                filename = str(command).replace(" ", "_")
                output.append(load_fixture(filename))
            return output

        self.run_commands.side_effect = load_from_file

    def test_ios_command_simple(self):
        set_module_args(dict(commands=["show version"]))
        result = self.execute_module()
        self.assertEqual(len(result["stdout"]), 1)
        self.assertTrue(result["stdout"][0].startswith("Cisco IOS Software"))

    def test_ios_command_multiple(self):
        set_module_args(dict(commands=["show version", "show version"]))
        result = self.execute_module()
        self.assertEqual(len(result["stdout"]), 2)
        self.assertTrue(result["stdout"][0].startswith("Cisco IOS Software"))

    def test_ios_command_wait_for(self):
        wait_for = 'result[0] contains "Cisco IOS"'
        set_module_args(dict(commands=["show version"], wait_for=wait_for))
        self.execute_module()

    def test_ios_command_wait_for_fails(self):
        wait_for = 'result[0] contains "test string"'
        set_module_args(dict(commands=["show version"], wait_for=wait_for))
        self.execute_module(failed=True)
        self.assertEqual(self.run_commands.call_count, 10)

    def test_ios_command_retries(self):
        wait_for = 'result[0] contains "test string"'
        set_module_args(dict(commands=["show version"], wait_for=wait_for, retries=2))
        self.execute_module(failed=True)
        self.assertEqual(self.run_commands.call_count, 3)

    def test_ios_command_retries_0(self):
        set_module_args(dict(commands=["show version"], retries=0))
        self.execute_module(failed=False)
        self.assertEqual(self.run_commands.call_count, 1)

    def test_ios_command_match_any(self):
        wait_for = ['result[0] contains "Cisco IOS"', 'result[0] contains "test string"']
        set_module_args(dict(commands=["show version"], wait_for=wait_for, match="any"))
        self.execute_module()

    def test_ios_command_match_all(self):
        wait_for = ['result[0] contains "Cisco IOS"', 'result[0] contains "IOSv Software"']
        set_module_args(dict(commands=["show version"], wait_for=wait_for, match="all"))
        self.execute_module()

    def test_ios_command_match_all_failure(self):
        wait_for = ['result[0] contains "Cisco IOS"', 'result[0] contains "test string"']
        commands = ["show version", "show version"]
        set_module_args(dict(commands=commands, wait_for=wait_for, match="all"))
        self.execute_module(failed=True)

    def test_ios_command_configure_check_warning(self):
        commands = ["configure terminal"]
        set_module_args({"commands": commands, "_ansible_check_mode": True})
        result = self.execute_module()
        self.assertEqual(
            result["warnings"],
            [
                "Only show commands are supported when using check mode, not executing configure terminal",
            ],
        )

    def test_ios_command_configure_not_warning(self):
        commands = ["configure terminal"]
        set_module_args(dict(commands=commands))
        result = self.execute_module()
        self.assertEqual(result["warnings"], [])

==> ansible-11.0.0a1.tar.gz: ansible-11.0.0a1/ansible_collections/cisco/ios/tests/unit/modules/network/ios/test_ios_command.py <==
# (c) 2016 Red Hat Inc.
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Ansible is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.

# Make coding more python3-ish
from __future__ import absolute_import, division, print_function


__metaclass__ = type
import json

from unittest.mock import patch

from ansible_collections.cisco.ios.plugins.modules import ios_command
from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args

from .ios_module import TestIosModule, load_fixture


class TestIosCommandModule(TestIosModule):
    module = ios_command

    def setUp(self):
        super(TestIosCommandModule, self).setUp()

        self.mock_run_commands = patch(
            "ansible_collections.cisco.ios.plugins.modules.ios_command.run_commands",
        )
        self.run_commands = self.mock_run_commands.start()

    def tearDown(self):
        super(TestIosCommandModule, self).tearDown()
        self.mock_run_commands.stop()

    def load_fixtures(self, commands=None):
        def load_from_file(*args, **kwargs):
            module, commands = args
            output = list()

            for item in commands:
                try:
                    obj = json.loads(item["command"])
                    command = obj["command"]
                except ValueError:
                    command = item["command"]
                filename = str(command).replace(" ", "_")
                output.append(load_fixture(filename))
            return output

        self.run_commands.side_effect = load_from_file

    def test_ios_command_simple(self):
        set_module_args(dict(commands=["show version"]))
        result = self.execute_module()
        self.assertEqual(len(result["stdout"]), 1)
        self.assertTrue(result["stdout"][0].startswith("Cisco IOS Software"))

    def test_ios_command_multiple(self):
        set_module_args(dict(commands=["show version", "show version"]))
        result = self.execute_module()
        self.assertEqual(len(result["stdout"]), 2)
        self.assertTrue(result["stdout"][0].startswith("Cisco IOS Software"))

    def test_ios_command_wait_for(self):
        wait_for = 'result[0] contains "Cisco IOS"'
        set_module_args(dict(commands=["show version"], wait_for=wait_for))
        self.execute_module()

    def test_ios_command_wait_for_fails(self):
        wait_for = 'result[0] contains "test string"'
        set_module_args(dict(commands=["show version"], wait_for=wait_for))
        self.execute_module(failed=True)
        self.assertEqual(self.run_commands.call_count, 10)

    def test_ios_command_retries(self):
        wait_for = 'result[0] contains "test string"'
        set_module_args(dict(commands=["show version"], wait_for=wait_for, retries=2))
        self.execute_module(failed=True)
        self.assertEqual(self.run_commands.call_count, 3)

    def test_ios_command_retries_0(self):
        set_module_args(dict(commands=["show version"], retries=0))
        self.execute_module(failed=False)
        self.assertEqual(self.run_commands.call_count, 1)

    def test_ios_command_match_any(self):
        wait_for = [
            'result[0] contains "Cisco IOS"',
            'result[0] contains "test string"',
        ]
        set_module_args(dict(commands=["show version"], wait_for=wait_for, match="any"))
        self.execute_module()

    def test_ios_command_match_all(self):
        wait_for = [
            'result[0] contains "Cisco IOS"',
            'result[0] contains "IOSv Software"',
        ]
        set_module_args(dict(commands=["show version"], wait_for=wait_for, match="all"))
        self.execute_module()

    def test_ios_command_match_all_failure(self):
        wait_for = [
            'result[0] contains "Cisco IOS"',
            'result[0] contains "test string"',
        ]
        commands = ["show version", "show version"]
        set_module_args(dict(commands=commands, wait_for=wait_for, match="all"))
        self.execute_module(failed=True)

    def test_ios_command_configure_check_warning(self):
        commands = ["configure terminal"]
        set_module_args({"commands": commands, "_ansible_check_mode": True})
        result = self.execute_module()
        self.assertEqual(
            result["warnings"],
            [
                "Only show commands are supported when using check mode, not executing configure terminal",
            ],
        )

    def test_ios_command_configure_not_warning(self):
        commands = ["configure terminal"]
        set_module_args(dict(commands=commands))
        result = self.execute_module()
        self.assertEqual(result["warnings"], [])
